@@ -1,6 +1,7 @@
 from requests import Session, Request
 from .response import Response
 import smartystreets_python_sdk as smarty
+import smartystreets_python_sdk_version as version
 
 
 class RequestsSender:
@@ -44,17 +45,20 @@ class RequestsSender:
 
 
 def build_request(smarty_request):
-    request = Request(url=smarty_request.url_prefix, params=smarty_request.parameters)
-    request.headers['User-Agent'] = "smartystreets (sdk:python@{})".format(smarty.__version__)
-    request.headers['Content-Type'] = smarty_request.content_type
-    if smarty_request.referer:
-        request.headers['Referer'] = smarty_request.referer
-    if smarty_request.payload:
-        request.data = smarty_request.payload
-        request.method = 'POST'
-    else:
-        request.method = 'GET'
-    return request
+    try:
+        request = Request(url=smarty_request.url_prefix, params=smarty_request.parameters)
+        request.headers['User-Agent'] = "smartystreets (sdk:python@{})".format(version.__version__)
+        request.headers['Content-Type'] = smarty_request.content_type
+        if smarty_request.referer:
+            request.headers['Referer'] = smarty_request.referer
+        if smarty_request.payload:
+            request.data = smarty_request.payload
+            request.method = 'POST'
+        else:
+            request.method = 'GET'
+        return request
+    except AttributeError:
+        return smarty_request
 
 
 def build_smarty_response(inner_response):
